import { SDKAPPID as sdkAppId, CHANNELID as channelId } from '../../config';
import { DigitsConsumer } from './DigitsConsumer';
Page({
  data: {
    status: 'loading',
    statusMap: {
      loading: 'loading', // 连接中
      cancel: 'cancel', // 已取消
      inProgress: 'inProgress', // 通话中
      finished: 'finished', // 通话结束
    },
    duration: 0,
    time: '00:00:00',
    image: {
      avatar: 'https://imgcache.qq.com/operation/dianshi/other/circle.539d85544b59d22d305d518be9fc63fcfa152d1c.svg',
      audioTrue:
        'https://imgcache.qq.com/operation/dianshi/other/audio-true.3c5b5a834d4ae418543dac481f5c3fcacf20ed7c.svg',
      audioFalse:
        'https://imgcache.qq.com/operation/dianshi/other/audio-false.c25cdc1fd2e624142f22c7be21016ef0172d675c.svg',
      speakerTrue:
        'https://imgcache.qq.com/operation/dianshi/other/speak-true.658aec3a6979a089492567997e8a1387c2f13546.svg',
      speakerFalse:
        'https://imgcache.qq.com/operation/dianshi/other/seaker-false.e8c4a5ad4207daea252b90821e749e79738da53f.svg',
      hangup: 'https://imgcache.qq.com/operation/dianshi/other/hangup.60bb3915a59187bb87a8f0d89763ebab97e7267e.svg',
      close: 'https://imgcache.qq.com/operation/dianshi/other/CLOSE.8445a839c6e7289a69147f7fce5c6e35eb88fc69.svg',
      deleteIcon: 'https://imgcache.qq.com/operation/dianshi/other/delete.d7d487e204d2a69c83b5704c4002f0b44f3af8f6.png',
    },
    enableMic: true,
    soundMode: 'speaker',
    sdkAppId: '',
    dialpadOpen: false,
    phoneNumber: '',
  },
  onLoad() {
    this.setData({
      sdkAppId,
    });
  },
  async onReady() {
    // eslint-disable-next-line @typescript-eslint/no-this-alias
    const self = this;
    try {
      await this.selectComponent('#tcccSdk').startCall({ channelId });
      this.digitsConsumer = new DigitsConsumer((digit) => self.selectComponent('#tcccSdk').sendDigits(digit));
    } catch (e) {
      wx.showToast({
        icon: 'error',
        title: e.message,
      });
    }
  },
  setSoundMode() {
    const change = this.data.soundMode === 'speaker' ? 'ear' : 'speaker';
    this.selectComponent('#tcccSdk').setSoundMode(change);
    this.setData({
      soundMode: change,
    });
  },
  setEnableMic() {
    if (this.data.enableMic) {
      this.selectComponent('#tcccSdk').muteAudio();
      this.setData({
        enableMic: false,
      });
    } else {
      this.selectComponent('#tcccSdk').unmuteAudio();
      this.setData({
        enableMic: true,
      });
    }
  },
  handleTcccError(e) {
    wx.showToast({
      icon: 'error',
      title: e.detail.message,
    });
  },
  handleHangup() {
    try {
      this.selectComponent('#tcccSdk').endCall();
    } catch (e) {
    } finally {
      this.setData({
        status: this.data.statusMap.finished,
      });
    }
  },
  handleEnd() {
    clearTimeout(this.durationTimer);
    this.setData({
      status: this.data.statusMap.finished,
    });
  },
  handleStart() {
    this.setData({
      status: this.data.statusMap.inProgress,
      duration: 1,
      time: '00:00:01',
    });
    this.timing();
  },
  // 通话
  handleAccept() {
    wx.showToast({
      title: '对方已接听',
      icon: 'success',
    });
  },
  handleClose() {
    wx.navigateBack();
  },
  timing() {
    this.durationTimer = setTimeout(() => {
      const time = this.sToTime(this.data.duration + 1);
      this.setData({
        duration: this.data.duration + 1,
        time,
      });
      this.timing();
    }, 1000);
  },
  sToTime(duration) {
    let seconds = `${Math.floor(duration % 60)}`;
    let minutes = `${Math.floor((duration / 60) % 60)}`;
    let hours = `${Math.floor((duration / (60 * 60)) % 24)}`;

    hours = +hours < 10 ? `0${hours}` : hours;
    minutes = +minutes < 10 ? `0${minutes}` : minutes;
    seconds = +seconds < 10 ? `0${seconds}` : seconds;
    return `${hours}:${minutes}:${seconds}`;
  },
  toggleDialpadOpen() {
    this.setData({
      dialpadOpen: !this.data.dialpadOpen,
    });
  },
  handleInputPhoneNumber(event) {
    const digit = event.detail;
    this.setData(
      {
        phoneNumber: [...this.data.phoneNumber.split(''), digit].join(''),
      },
      () => {
        this.digitsConsumer.start(digit);
      },
    );
  },
  handleDelete() {
    this.setData({
      phoneNumber: this.data.phoneNumber.slice(0, -1),
    });
  },
});
